==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/InstytucjaWplata.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class InstytucjaWplata extends GenericDPSObject {
    /**
     * INSTYTUCJA_WPLATA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * INSTYTUCJA_WPLATA.INSTYTUCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long instytucjaId;

    /**
     * INSTYTUCJA_WPLATA.DATA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date data;

    /**
     * INSTYTUCJA_WPLATA.ROK
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer rok;

    /**
     * INSTYTUCJA_WPLATA.MIESIAC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer miesiac;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return INSTYTUCJA_WPLATA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * INSTYTUCJA_WPLATA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return INSTYTUCJA_WPLATA.INSTYTUCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getInstytucjaId() {
        return instytucjaId;
    }

    /**
     * INSTYTUCJA_WPLATA.INSTYTUCJA_ID
     *
     * @param instytucjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setInstytucjaId(Long instytucjaId) {
        this.instytucjaId = instytucjaId;
    }

    /**
     * @return INSTYTUCJA_WPLATA.DATA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getData() {
        return data;
    }

    /**
     * INSTYTUCJA_WPLATA.DATA
     *
     * @param data
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return INSTYTUCJA_WPLATA.ROK
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getRok() {
        return rok;
    }

    /**
     * INSTYTUCJA_WPLATA.ROK
     *
     * @param rok
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRok(Integer rok) {
        this.rok = rok;
    }

    /**
     * @return INSTYTUCJA_WPLATA.MIESIAC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getMiesiac() {
        return miesiac;
    }

    /**
     * INSTYTUCJA_WPLATA.MIESIAC
     *
     * @param miesiac
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setMiesiac(Integer miesiac) {
        this.miesiac = miesiac;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        InstytucjaWplata other = (InstytucjaWplata) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getInstytucjaId() == null ? other.getInstytucjaId() == null : this.getInstytucjaId().equals(other.getInstytucjaId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getRok() == null ? other.getRok() == null : this.getRok().equals(other.getRok()))
            && (this.getMiesiac() == null ? other.getMiesiac() == null : this.getMiesiac().equals(other.getMiesiac()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getInstytucjaId() == null) ? 0 : getInstytucjaId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getRok() == null) ? 0 : getRok().hashCode());
        result = prime * result + ((getMiesiac() == null) ? 0 : getMiesiac().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", instytucjaId=").append(instytucjaId);
        sb.append(", data=").append(data);
        sb.append(", rok=").append(rok);
        sb.append(", miesiac=").append(miesiac);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/InstytucjaWplata.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class InstytucjaWplata extends GenericDPSObject {
    /**
     * INSTYTUCJA_WPLATA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * INSTYTUCJA_WPLATA.INSTYTUCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long instytucjaId;

    /**
     * INSTYTUCJA_WPLATA.DATA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date data;

    /**
     * INSTYTUCJA_WPLATA.ROK
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer rok;

    /**
     * INSTYTUCJA_WPLATA.MIESIAC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer miesiac;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return INSTYTUCJA_WPLATA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * INSTYTUCJA_WPLATA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return INSTYTUCJA_WPLATA.INSTYTUCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getInstytucjaId() {
        return instytucjaId;
    }

    /**
     * INSTYTUCJA_WPLATA.INSTYTUCJA_ID
     *
     * @param instytucjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setInstytucjaId(Long instytucjaId) {
        this.instytucjaId = instytucjaId;
    }

    /**
     * @return INSTYTUCJA_WPLATA.DATA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getData() {
        return data;
    }

    /**
     * INSTYTUCJA_WPLATA.DATA
     *
     * @param data
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return INSTYTUCJA_WPLATA.ROK
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getRok() {
        return rok;
    }

    /**
     * INSTYTUCJA_WPLATA.ROK
     *
     * @param rok
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRok(Integer rok) {
        this.rok = rok;
    }

    /**
     * @return INSTYTUCJA_WPLATA.MIESIAC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getMiesiac() {
        return miesiac;
    }

    /**
     * INSTYTUCJA_WPLATA.MIESIAC
     *
     * @param miesiac
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setMiesiac(Integer miesiac) {
        this.miesiac = miesiac;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        InstytucjaWplata other = (InstytucjaWplata) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getInstytucjaId() == null ? other.getInstytucjaId() == null : this.getInstytucjaId().equals(other.getInstytucjaId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getRok() == null ? other.getRok() == null : this.getRok().equals(other.getRok()))
            && (this.getMiesiac() == null ? other.getMiesiac() == null : this.getMiesiac().equals(other.getMiesiac()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getInstytucjaId() == null) ? 0 : getInstytucjaId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getRok() == null) ? 0 : getRok().hashCode());
        result = prime * result + ((getMiesiac() == null) ? 0 : getMiesiac().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", instytucjaId=").append(instytucjaId);
        sb.append(", data=").append(data);
        sb.append(", rok=").append(rok);
        sb.append(", miesiac=").append(miesiac);
        sb.append("]");
        return sb.toString();
    }
}
